# Papersurfer

Automatically download paper list from Mattermost channel and display.

# UI

![](screencast.gif)


# Direct export

# Jupyter Notebook

# Database

Papersurfer uses a tinydb database to cache retrieved data, mostly because I
intensely dislike sql-databases.python setup.py install --record files.txt
